# pedon

*from Greek: πέδον, pedon -> soil*

Python package for (unsaturated) soil properties including pedotransfer functions. This package takes an object-oriented approach to soils, soil samples and soil models. Soil models include:
- Mualem - Van Genuchten
- Brooks - Corey
- Fredlund & Xing
- Gardner
- Sorab Panday (Modflow-USG)
